@@ -50,7 +50,6 @@ typedef struct _FORMULA_ARRAY_DATA
 
 typedef struct _FORMULA_OP_DATA
 {
-  BYTE formula_ptg ;
   gboolean infix ; /* ie. not unary */
   char *mid ;
   int  precedence ;
@@ -58,12 +57,8 @@ typedef struct _FORMULA_OP_DATA
 
 typedef struct _FORMULA_FUNC_DATA
 {
-	int function_idx ;
 	char *prefix ;
-	char *mid ;
-	char *suffix ;
 	int num_args ; /* -1 for multi-arg */
-	int precedence ;
 } FORMULA_FUNC_DATA ;
 
 #endif
