@@ -4,7 +4,7 @@
  *
  * Vincent Renardias <vincent@ldsol.com>
  *
- * $Id: csv-io.c,v 1.4 1999/02/22 21:28:18 unammx Exp $
+ * $Id: csv-io.c,v 1.5 1999/03/11 18:54:53 unammx Exp $
  */
 
 /*
@@ -17,7 +17,7 @@
 #include <stdlib.h>
 #include <gnome.h>
 #include <unistd.h>
-#include <sys/fcntl.h>
+#include <fcntl.h>
 #include <sys/mman.h>
 #include <sys/stat.h>
 #include <sys/types.h>
