@@ -3,7 +3,7 @@
  *
  * Daniel Veillard <Daniel.Veillard@w3.org>
  *
- * $Id: xml-io.c,v 1.33 1999/03/13 23:35:17 unammx Exp $
+ * $Id: xml-io.c,v 1.34 1999/03/23 13:02:16 veillard Exp $
  */
 
 #include <config.h>
@@ -1207,7 +1207,8 @@ writeXmlCell (parseXmlContextPtr ctxt, Cell *cell)
 	if (child)
 		xmlAddChild (cur, child);
 	text = cell_get_content (cell);
-	xmlNewChild(cur, ctxt->ns, "Content", text);
+	xmlNewChild(cur, ctxt->ns, "Content",
+	            xmlEncodeEntities(ctxt->doc, text));
 	g_free (text);
 
 	return cur;
